# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

######################### We start with some black magic to print on failure.

# Change 1..1 below to 1..last_test_to_print .
# (It may become useful if the test is moved to ./t subdirectory.)

BEGIN { $| = 1; print "1..3\n"; }
END {print "not ok 1\n" unless $loaded;}
$loaded = 1;
print "ok 1\n";

######################### End of black magic.

# Insert your test code below (better if it prints "ok 13"
# (correspondingly "not ok 13") depending on the success of chunk 13
# of the test code):
use lib qw(./blib/lib .);
use Inline 'WebChat';

my $out;
eval { $out = whatever('foo') };
unless ($@)
{
        print "ok 2\n";
} else {
        print "not ok 2\n";
}

if ($out eq 'foo')
{
	print "ok 3\n";
} else {
	print "not ok 3\n";
}

__END__

__WebChat__

sub whatever
{

        # this has no web chat stuff in it 
        # because that would require you to
        # be connected to the net
        # which would be bad
        return $_[0];
 
}

